import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex)

export default new Vuex.Store({
    state: {
        ws_connected: false,
        notifications: [],
        scan_cache: {}
    },
    getters: {
        getScansByTarget(state, target){
            return state.scan_cache[target]
        }
    },
    actions: {
        getScansByTarget({ commit }, target){
            fetch('/api/v1/scans/' + target)
                .then(resp => resp.json())
                .then(json => {
                    commit("SET_SCANS", { target, data: json.data });
                });
        },
    },
    mutations: {
        "SET_SCANS"(state, { target, data }) {
            console.log("SET_SCANS: ", target, data)
            Vue.set(state.scan_cache, target, data)
        },
        "SOCKET_connect"(state) {
            state.ws_connected = true
        },
        "SOCKET_disconnect"(state) {
            state.ws_connected = false
        },
        "SOCKET_message"(state, message) {
            // Update progress queue
            let matchedItem = state.notifications.find(item => item.id == message.id);
            if (matchedItem)
                Object.keys(message).forEach(key => {
                    Vue.set(matchedItem, key, message[key])
                });
            else
                state.notifications.push(message);

            // Update scan cache
            if (!state.scan_cache[message.target]) {
                Vue.set(state.scan_cache, message.target, [message])
            } else {
                let matchedItem = state.scan_cache[message.target]
                    .find(item => item.id == message.id);

                if (matchedItem)
                    Object.keys(message).forEach(key => {
                        Vue.set(matchedItem, key, message[key])
                    });
                else
                    state.scan_cache[message.target].unshift(message);
            }
        }
    },
})
